ALTER TABLE `cat_configuracion`
ADD COLUMN `url_sync_empresa` TEXT NULL AFTER `url_existencias`;

UPDATE cat_configuracion
SET url_sync_empresa = 'http://hks.softnet.com.mx/ERP/sync_empresa.php';


ALTER TABLE `tbl_cortes_caja`
ADD COLUMN `desglose` TEXT NULL AFTER `id_usuario_corte`,
ADD COLUMN `consecutivo` INT(11) NULL AFTER `fecha_corte`;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_precioProductoNew`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_precioProductoNew`(
	in_id_sucursal INT, 	
	in_id_producto INT, 	
	in_cantidad INT 	
)
    COMMENT 'Obtiene la imagen por default para productos sin foto'
BEGIN
	SET @precio_unitario = NULL;
	SET @precio_mayoreo = 0.00;
	SET @oferta = 0;
	SET @cantidad = 0;
	
	
	SELECT pof.precio,
		pof.precio,
		1 AS oferta
	INTO @precio_unitario,
		@precio_mayoreo,
		@oferta
	FROM tbl_precios_ofertas AS pof
	WHERE pof.id_producto = in_id_producto
		AND pof.id_sucursal IN (0, in_id_sucursal)
		AND ( pof.fecha_desde IS NULL AND pof.fecha_hasta IS NULL
			OR pof.fecha_desde IS NULL AND CURDATE() <= pof.fecha_hasta
			OR CURDATE() >= pof.fecha_desde AND pof.fecha_hasta IS NULL
			OR CURDATE() BETWEEN pof.fecha_desde AND pof.fecha_hasta
		)
	ORDER BY pof.id_sucursal DESC
	LIMIT 1;
	
	
	IF ISNULL(@precio_unitario) THEN
		
		IF EXISTS (
			SELECT ppro.id_producto
			FROM tbl_precios_productos AS ppro
			WHERE ppro.id_sucursal = in_id_sucursal
				AND ppro.id_producto = in_id_producto
		) THEN
			
			
			
			SELECT COALESCE(pp.precio, prd.precio_venta),
				COALESCE(( 
					SELECT pma.precio
					FROM tbl_precios_mayoreo AS pma
					WHERE pma.id_producto = in_id_producto
						AND pma.id_sucursal IN (0, in_id_sucursal)
					ORDER BY pma.id_sucursal DESC
					LIMIT 1
				), pp.precio, prd.precio_venta),
				COALESCE(pp.cantidad, 0)
			INTO @precio_unitario,
				@precio_mayoreo,
				@cantidad
			FROM cat_productos_servicios AS prd
			JOIN cat_sucursales AS suc
				ON suc.id_sucursal = in_id_sucursal
			LEFT OUTER JOIN tbl_precios_productos AS pp
				ON pp.id_producto = prd.id_producto
					AND pp.id_sucursal = in_id_sucursal
					AND pp.cantidad <= in_cantidad
			WHERE prd.id_producto = in_id_producto
			ORDER BY pp.cantidad DESC
			LIMIT 1;
		ELSE
			
			
			
			
			SELECT COALESCE(pp.precio, prd.precio_venta),
				COALESCE(( 
					SELECT pma.precio
					FROM tbl_precios_mayoreo AS pma
					WHERE pma.id_producto = in_id_producto
						AND pma.id_sucursal IN (0, in_id_sucursal)
					ORDER BY pma.id_sucursal DESC
					LIMIT 1
				), pp.precio, prd.precio_venta),
				COALESCE(pp.cantidad, 0)
			INTO @precio_unitario,
				@precio_mayoreo,
				@cantidad
			FROM cat_productos_servicios AS prd
			JOIN cat_sucursales AS suc
				ON suc.id_sucursal = in_id_sucursal
			LEFT OUTER JOIN tbl_precios_productos AS pp
				ON pp.id_producto = prd.id_producto
					AND pp.id_sucursal = 0 
					AND pp.cantidad <= in_cantidad
			WHERE prd.id_producto = in_id_producto
			ORDER BY pp.cantidad DESC
			LIMIT 1;
		END IF;
	END IF;
	
	SELECT @precio_unitario AS precio_unitario,
		@precio_mayoreo AS precio_mayoreo,
		@cantidad AS cantidad_precio,
		@oferta AS precio_oferta;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_insertarCorteCaja`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_insertarCorteCaja`(
	in_efectivo_caja DECIMAL(15,2),
	in_efectivo_real DECIMAL(15,2),
	in_id_user_caja INT,
	in_id_user_corte INT,
	in_desglose TEXT
)
    COMMENT 'Agregar registro de corte de caja'
BEGIN
	SET @fecStr = DATE_FORMAT(CURDATE(), '%Y%m%d');
	
	START TRANSACTION;
	SET @consecutivo = (
		SELECT COALESCE(MAX(consecutivo), 0) + 1
		FROM tbl_cortes_caja
		WHERE CAST(fecha_corte AS DATE) = CURDATE()
	);
	
	
	INSERT INTO tbl_cortes_caja
	SET fecha_corte = NOW(),
		consecutivo = @consecutivo,
		efectivo_caja = in_efectivo_caja,
		efectivo_real = in_efectivo_real,
		diferencia = efectivo_real - efectivo_caja,
		id_usuario_caja = in_id_user_caja,
		id_usuario_corte = in_id_user_corte,
		desglose = in_desglose;
	
	SET @id = LAST_INSERT_ID();
	COMMIT;
	
	-- Retorna ID del movimiento y # de Referencia
	SELECT @id AS id_corte;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_configuracion`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_configuracion`()
    SQL SECURITY INVOKER
    COMMENT 'Obtiene la información de configuración'
BEGIN
	SELECT cfg.id_sucursal,
		cfg.default_image,
		cfg.group_len,
		cfg.desglosa_total,
		cfg.cashdrawer_unc,
		cfg.url_existencias,
		cfg.url_sync_empresa,
		cfg.url_sync_sucursales,
		cfg.url_sync_productos,
		cfg.url_sync_precios,
		cfg.url_sync_usuarios,
		cfg.url_sync_ventas,
		cfg.token,
		COALESCE(cfg.logo, '') AS logo,
		cfg.print_hoffset
	FROM cat_configuracion AS cfg;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateUrls`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateUrls`(
	in_url_empresa TEXT,
	in_url_sucursales TEXT,
	in_url_productos TEXT,
	in_url_precios TEXT,
	in_url_existencias TEXT,
	in_url_ventas TEXT
)
    COMMENT 'Guarda la configuracion de Urls para sincronizacion de catalogos'
BEGIN
	UPDATE cat_configuracion
	SET url_sync_empresa = in_url_empresa,
		url_sync_sucursales = in_url_sucursales,
		url_sync_productos = in_url_productos,
		url_sync_precios = in_url_precios,
		url_existencias = in_url_existencias,
		url_sync_ventas = in_url_ventas;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateEmpresa`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateEmpresa`(
	in_logo TEXT
)
    COMMENT 'Guarda la información de la empresa'
BEGIN
	UPDATE cat_configuracion
	SET logo = in_logo;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_insertarCorteCaja`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_insertarCorteCaja`(
	in_efectivo_caja DECIMAL(15,2),
	in_efectivo_real DECIMAL(15,2),
	in_id_user_caja INT,
	in_id_user_corte INT,
	in_desglose TEXT
)
    COMMENT 'Agregar registro de corte de caja'
BEGIN
	SET @fecStr = DATE_FORMAT(CURDATE(), '%Y%m%d');
	
	START TRANSACTION;
	SET @consecutivo = (
		SELECT COALESCE(MAX(consecutivo), 0) + 1
		FROM tbl_cortes_caja
		WHERE CAST(fecha_corte AS DATE) = CURDATE()
	);
	
	
	INSERT INTO tbl_cortes_caja
	SET fecha_corte = NOW(),
		consecutivo = @consecutivo,
		efectivo_caja = in_efectivo_caja,
		efectivo_real = in_efectivo_real,
		diferencia = efectivo_real - efectivo_caja,
		id_usuario_caja = in_id_user_caja,
		id_usuario_corte = in_id_user_corte,
		desglose = in_desglose;
	
	SET @id = LAST_INSERT_ID();
	COMMIT;
	
	-- Retorna ID del movimiento y # de Referencia
	SELECT @id AS id_corte;
END$$

DELIMITER ;
